package com.aicc.livechat_sdk_flutter.channel;

import android.content.Context;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.widget.ImageView;

import com.aicc.livechat_sdk_flutter.R;
import com.aicc.livechat_sdk_flutter.activity.SessionActivity;
import com.bumptech.glide.Glide;
import com.bumptech.glide.load.DataSource;
import com.bumptech.glide.load.engine.GlideException;
import com.bumptech.glide.request.RequestListener;
import com.bumptech.glide.request.target.CustomTarget;
import com.bumptech.glide.request.target.Target;
import com.bumptech.glide.request.transition.Transition;
import com.tinet.oskit.TOSClientKit;
import com.tinet.oskit.fragment.SessionFragment;
import com.tinet.oskit.listener.TImageLoader;
import com.tinet.oskit.listener.TImageLoaderListener;
import com.tinet.oslib.config.TOSConnectOption;
import com.tinet.oslib.config.TOSInitOption;
import com.tinet.oslib.listener.OnlineConnectResultCallback;
import com.tinet.oslib.model.bean.CardInfo;
import com.tinet.oslib.model.bean.LabeInfo;
import com.tinet.timclientlib.utils.TLogUtils;

import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;

/**
 * @ProjectName: android
 * @ClassName: CustomMethodChannel
 * @Author: zhangping
 * @CreateDate: 2023/3/9 15:15
 * @Description: 自定义MethodChannel类
 */
public class CustomMethodChannel implements MethodChannel.MethodCallHandler {

    private Context mContext;

    private final String methodInitPlugin = "method_init_plugin";

    private final String methodEnterSession = "method_enter_session";

    private final String methodDisconnect = "method_disconnect";

    private final String methodGetCurrentUserInfo = "method_get_current_user_info";

    private final String methodGetCurrentSessionInfo = "method_get_current_session_info";

    private final String methodGetCurrentOnlineStatus = "method_get_current_online_status";

    private final String methodUpdateSessionWindowQuickEntry = "method_update_session_window_quick_entry";

    private final String methodGetSdkVersion = "method_get_sdk_version";

    public CustomMethodChannel(FlutterPlugin.FlutterPluginBinding flutterPluginBinding) {
        mContext = flutterPluginBinding.getApplicationContext();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull MethodChannel.Result result) {
        if (call.method.equals(methodInitPlugin)) {
            detailInitPlugin(call, result);
        } else if (call.method.equals(methodEnterSession)) {
            detailEnterSession(call, result);
        } else if (call.method.equals(methodDisconnect)) {
            TOSClientKit.disConnect(false, null);
            result.success(true);
        } else if (call.method.equals(methodGetCurrentUserInfo)) {
            result.success(TOSClientKit.getCurrentUserInfo().toJson().toString());
        } else if (call.method.equals(methodGetCurrentSessionInfo)) {
            result.success(TOSClientKit.getCurrentSessionInfo().toString());
        } else if (call.method.equals(methodGetCurrentOnlineStatus)) {
            result.success(TOSClientKit.getCurrentOnlineStatus());
        } else if (call.method.equals(methodUpdateSessionWindowQuickEntry)) {
            detailUpdateSessionWindowQuickEntry(call, result);
        } else if (call.method.equals(methodGetSdkVersion)) {
            result.success(TOSClientKit.getSDKVersion());
        } else {
            result.notImplemented();
        }
    }

    /**
     * 处理初始化SDK
     *
     * @param call
     * @param result
     */
    private void detailInitPlugin(MethodCall call, MethodChannel.Result result) {
        TOSInitOption tOSInitOption = new TOSInitOption();
        if (call.hasArgument("accessId")) {
            tOSInitOption.setAccessId(Objects.requireNonNull(call.argument("accessId")).toString());
        } else {
            result.success(false);
            return;
        }
        if (call.hasArgument("accessSecret")) {
            tOSInitOption.setAccessSecret(Objects.requireNonNull(call.argument("accessSecret")).toString());
        } else {
            result.success(false);
            return;
        }
        if (call.hasArgument("enterpriseId")) {
            tOSInitOption.setEnterpriseId(Long.valueOf(call.argument("enterpriseId")));
        } else {
            result.success(false);
            return;
        }
        if (call.hasArgument("apiUrl")) {
            tOSInitOption.setApiUrl(Objects.requireNonNull(call.argument("apiUrl")).toString());
        } else {
            result.success(false);
            return;
        }
        if (call.hasArgument("onlineUrl")) {
            tOSInitOption.setOnlineUrl(Objects.requireNonNull(call.argument("onlineUrl")).toString());
        } else {
            result.success(false);
            return;
        }
        if (call.hasArgument("debug")) {
            boolean debug = Boolean.TRUE.equals(call.argument("debug"));
            tOSInitOption.setDebug(debug);
        }

        TOSClientKit.initSDK(mContext, tOSInitOption, new TImageLoader() {
            @Override
            public void loadImage(ImageView imageView, Object uri) {
                Glide.with(imageView.getContext()).load(uri).error(R.drawable.ti_ic_load_default_image).placeholder(R.drawable.ti_ic_load_default_image).into(imageView);
            }

            @Override
            public void loadImage(ImageView imageView, Object uri, int placeholderImg, int errorImg) {
                Glide.with(imageView.getContext()).load(uri).override(CustomTarget.SIZE_ORIGINAL, CustomTarget.SIZE_ORIGINAL).error(errorImg).placeholder(placeholderImg).into(imageView);
            }

            @Override
            public void loadImage(ImageView imageView, Object uri, int originalWidth, int originalHeight, TImageLoaderListener listener) {
                Glide.with(imageView.getContext()).load(uri).override(originalWidth, originalHeight).listener(new ImageRequestListener(listener)).error(R.drawable.ti_ic_load_default_image).placeholder(R.drawable.ti_ic_load_default_image).into(imageView);
            }

            @Override
            public void loadImage(Context context, Object uri, int originalWidth, int originalHeight, TImageLoaderListener listener) {
                Glide.with(context).load(uri).override(originalWidth, originalHeight).into(new CustomTarget<Drawable>() {
                    @Override
                    public void onResourceReady(@NonNull Drawable resource, @Nullable Transition<? super Drawable> transition) {
                        if (null != listener) {
                            listener.onResourceReady(resource);
                        }
                    }

                    @Override
                    public void onLoadCleared(@Nullable Drawable placeholder) {
                        if (null != listener) {
                            listener.onLoadFailed();
                        }
                    }
                });
            }
        });

        result.success(true);
    }

    /**
     * 处理进入会话
     *
     * @param call
     * @param result
     */
    private void detailEnterSession(final MethodCall call, MethodChannel.Result result) {
        try {
            TOSConnectOption tosConnectOption = new TOSConnectOption();
            if (call.hasArgument("visitorId")) {
                tosConnectOption.setVisitorId(Objects.requireNonNull(call.argument("visitorId")).toString());
            }
            if (call.hasArgument("nickname")) {
                tosConnectOption.setNickname(Objects.requireNonNull(call.argument("nickname")).toString());
            }
            if (call.hasArgument("headUrl")) {
                tosConnectOption.setHeadUrl(Objects.requireNonNull(call.argument("headUrl")).toString());
            }
            if (call.hasArgument("mobile")) {
                tosConnectOption.setMobile(Objects.requireNonNull(call.argument("mobile")).toString());
            }
            if (call.hasArgument("advanceParams")) {
                tosConnectOption.setAdvanceParams(call.argument("advanceParams"));
            }
            // : 2023/3/2 处理商品卡片
            CardInfo mCardInfo = null;
            if (call.hasArgument("cardInfo")) {
                Map<String, Object> cardInfoMap = call.argument("cardInfo");
                if (cardInfoMap != null) {
                    JSONObject cardInfoObj = new JSONObject(cardInfoMap);
                    mCardInfo = CardInfo.fromJson(cardInfoObj);
                }
            }
            CardInfo finalMCardInfo = mCardInfo;

            TOSClientKit.connect(tosConnectOption, new OnlineConnectResultCallback() {
                @Override
                public void onSuccess() {
                    Intent intent = new Intent(mContext, SessionActivity.class);
                    if (finalMCardInfo != null) {
                        Bundle bundle = new Bundle();
                        bundle.putParcelable(SessionFragment.ARGS_CARD, finalMCardInfo);
                        intent.putExtra("bundle", bundle);
                    }
                    if (call.hasArgument("title")) {
                        intent.putExtra("title", Objects.requireNonNull(call.argument("title")).toString());
                    }
                    intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                    mContext.startActivity(intent);
                    result.success(true);
                }

                @Override
                public void onError(int errorCode, String errorDesc) {
                    TLogUtils.e(errorDesc);
                    result.error("" + errorCode, errorDesc, errorDesc);
                }
            });

        } catch (Exception e) {
            result.success(true);
            e.printStackTrace();
        }
    }

    /**
     * 处理更新快捷入口
     *
     * @param call
     * @param result
     */
    private void detailUpdateSessionWindowQuickEntry(MethodCall call, MethodChannel.Result result) {
        if (call.hasArgument("quickList")) {
            List<LabeInfo> labeInfos = new ArrayList<>();
            ArrayList<Map<String, String>> quickList = call.argument("quickList");
            if (quickList != null) {
                for (int i = 0; i < quickList.size(); i++) {
                    LabeInfo labeInfo = new LabeInfo(quickList.get(i).get("name"), quickList.get(i).get("value"));
                    labeInfos.add(labeInfo);
                }
            }
            if (labeInfos.size() > 0) {
                TOSClientKit.updateSessionWindowQuickEntrys(new ArrayList<>());
            }
        }
        result.success(true);
    }


    /**
     * 自定义图片加载listener
     */
    class ImageRequestListener implements RequestListener<Drawable> {

        private TImageLoaderListener listener;

        public ImageRequestListener(TImageLoaderListener listener) {
            this.listener = listener;
        }

        @Override
        public boolean onLoadFailed(@Nullable GlideException e, Object model, Target<Drawable> target, boolean isFirstResource) {
            if (null != listener) {
                listener.onLoadFailed();
            }

            return false;
        }

        @Override
        public boolean onResourceReady(Drawable resource, Object model, Target<Drawable> target, DataSource dataSource, boolean isFirstResource) {
            if (null != listener) {
                listener.onResourceReady(resource);
            }
            return false;
        }
    }
}
