package com.aicc.livechat_sdk_flutter.fragment;

import android.view.View;
import android.widget.Toast;

import com.aicc.livechat_sdk_flutter.listener.TListenerManager;
import com.tinet.oskit.TOSClientKit;
import com.tinet.oskit.fragment.SessionFragment;
import com.tinet.oskit.listener.FuncListener;
import com.tinet.oskit.listener.LabelListener;
import com.tinet.oskit.listener.SessionClickListener;
import com.tinet.oskit.listener.impl.FuncListenerImpl;
import com.tinet.oskit.listener.impl.LabelListenerImpl;
import com.tinet.oskit.listener.impl.SessionClickListenerImpl;
import com.tinet.oskit.model.Function;
import com.tinet.oslib.manager.OnlineMessageManager;
import com.tinet.oslib.model.bean.LabeInfo;
import com.tinet.oslib.model.bean.LogisticsCardInfo;
import com.tinet.oslib.model.bean.SessionInfo;
import com.tinet.oslib.model.message.OnlineMessage;
import com.tinet.oslib.model.message.content.ChatInvestigationMessage;
import com.tinet.oslib.model.message.content.ChatLeaveMessage;
import com.tinet.oslib.model.message.content.ChatMiniProgramCardMessage;
import com.tinet.oslib.model.message.content.TextMessage;
import com.tinet.timclientlib.utils.TLogUtils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import androidx.annotation.NonNull;

/**
 * @ProjectName: TIMSDK
 * @ClassName: ChatFragment
 * @Author: liuzr
 * @CreateDate: 2021-10-11 19:11
 * @Description:
 */
public class ChatFragment extends SessionFragment {


    public ChatFragment() {
    }

    @Override
    public void onResume() {
        super.onResume();
        TOSClientKit.setOnlineStatusListener(new OnlineMessageManager.OnlineStatusListener() {
            @Override
            public void onStatusChanged(int status) {
                if (status != 0) {
                    // : 2022/7/21 只有在进入会话页面后，才可获取会话信息
                    SessionInfo currentSessionInfo = TOSClientKit.getCurrentSessionInfo();
                    TLogUtils.i("当前会话 mainUniqueId:" + currentSessionInfo.getMainUniqueId());
                }
            }
        });
    }

    @Override
    protected SessionClickListener getListener() {
        return new SessionClickListenerImpl(this) {


            @Override
            public void onClick(View itemView, OnlineMessage message) {
                super.onClick(itemView, message);
                TLogUtils.i("消息点击事件" + message.getMessageUUID());
                onEventListener("onClick", message.toJson().toString());
            }

            @Override
            public void onLongClick(View itemView, OnlineMessage message) {
                super.onLongClick(itemView, message);
                TLogUtils.i("消息长按事件" + message.getMessageUUID());
                onEventListener("onLongClick", message.toJson().toString());
            }

            @Override
            public void onLinkClick(String url) {
                super.onLinkClick(url);
                // 自定义超链接事件
                Toast.makeText(requireContext(), "超链接地址：" + url, Toast.LENGTH_SHORT).show();
                onEventListener("onLinkClick", url);
            }

            @Override
            public void onLinkClick(String content, String messageEventType) {
                super.onLinkClick(content, messageEventType);
                TLogUtils.i("onLinkClick :content=" + content + "  messageEventType=" + messageEventType);
                Toast.makeText(requireContext(), "内容：" + content + "  类型：" + messageEventType, Toast.LENGTH_SHORT).show();
                onEventListener("onLinkClick", messageEventType, content);
            }

            @Override
            public void videoPlay(String url) {
                super.videoPlay(url);
                // 自定义视频播放，如果需要自己实现视频播放，则需要屏蔽super.videoPlay(url);父类的实现方式
                onEventListener("videoPlay", url);
            }

            @Override
            public void downloadFile(String url, String name) {
                super.downloadFile(url, name);
                TLogUtils.d("下载链接为：" + url);
                onEventListener("downloadFile", url);
            }

            @Override
            public void onCardMessageClick(View itemView, OnlineMessage message) {
                super.onCardMessageClick(itemView, message);
                onEventListener("onCardMessageClick", message.toJson().toString());
            }

            @Override
            public void onStartRequestPermissionsCallback(@NonNull String[] permissions, int requestCode) {
                super.onStartRequestPermissionsCallback(permissions, requestCode);
                onEventListener("onStartRequestPermissionsCallback", String.valueOf(requestCode), Arrays.toString(permissions));
            }

            @Override
            public void reEditMessage(TextMessage message) {
                super.reEditMessage(message);
                onEventListener("reEditMessage", message.toJson().toString());
            }

            @Override
            public void resendMessage(OnlineMessage message) {
                super.resendMessage(message);
                onEventListener("resendMessage", message.toJson().toString());
            }

            @Override
            public void onImageMessageClick(ArrayList<String> messages, int index) {
                super.onImageMessageClick(messages, index);
            }

            @Override
            public void onCardMessageClickSendOut(OnlineMessage message) {
                super.onCardMessageClickSendOut(message);
                onEventListener("onCardMessageClickSendOut", message.toJson().toString());
            }

            @Override
            public void onLogisticsCardButtonClick(LogisticsCardInfo logisticsCardInfo) {
                super.onLogisticsCardButtonClick(logisticsCardInfo);
//                onEventListener("onLogisticsCardButtonClick", logisticsCardInfo);
            }

            @Override
            public void onQuestionRequest(String info) {
                super.onQuestionRequest(info);
            }

            @Override
            public void onQuestionRequest(String info, String knowledge) {
                super.onQuestionRequest(info, knowledge);
            }

            @Override
            public void onMiniProgramCardClick(ChatMiniProgramCardMessage miniProgramCardMessage) {
                super.onMiniProgramCardClick(miniProgramCardMessage);
                onEventListener("onMiniProgramCardClick", miniProgramCardMessage.getContent());
            }

            @Override
            public void cancelQueue() {
                super.cancelQueue();
            }

            @Override
            public void onEvaluateInvestigationClick(ChatInvestigationMessage message) {
                super.onEvaluateInvestigationClick(message);
            }
        };
    }

    private void onEventListener(String eventName, String eventContent) {
        if (TListenerManager.getInstance().getTEventChannelListener() != null) {
            TListenerManager.getInstance().getTEventChannelListener().onEventHandler(eventName, eventContent);
        }
    }

    private void onEventListener(String eventName, String eventType, String eventContent) {
        if (TListenerManager.getInstance().getTEventChannelListener() != null) {
            TListenerManager.getInstance().getTEventChannelListener().onEventHandler(eventName, eventType, eventContent);
        }
    }

    @Override
    public void funcList(List<Function> funcs) {
        if (null == funcs) {
            funcs = new ArrayList<>();
        }
        funcs.clear();

        funcs.add(new Function(Function.TYPE_SYSTEM, Function.SEND_IMAGE));
        funcs.add(new Function(Function.TYPE_SYSTEM, Function.SEND_VIDEO));
        funcs.add(new Function(Function.TYPE_SYSTEM, Function.SEND_FILE));
        funcs.add(new Function(Function.TYPE_SYSTEM, Function.TO_ONLINE));
        funcs.add(new Function(Function.TYPE_SYSTEM, Function.CHAT_OVER));
        super.funcList(funcs);
    }

    @Override
    protected FuncListener getFuncListener() {
        //ODO 自定义底部功能栏
        return new FuncListenerImpl(this) {
            @Override
            public void onFuncClick(Function func) {
                super.onFuncClick(func);
            }
        };
    }

    //快捷入口的点击
    @Override
    protected LabelListener getLabelListener() {
        return new LabelListenerImpl(this) {
            @Override
            public void onLabelClick(LabeInfo labeInfo) {
                super.onLabelClick(labeInfo);
                Toast.makeText(requireContext(), labeInfo.toString(), Toast.LENGTH_SHORT).show();
                onEventListener("onLabelClick", labeInfo.toString());
            }
        };
    }


    @Override
    public void chatLeaveMessage(ChatLeaveMessage message) {
        super.chatLeaveMessage(message);//自定义实现留言
        // 自定义实现标题栏样式
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
    }
}
