import 'package:flutter/material.dart';
import 'package:livechat_sdk_flutter/livechat_sdk_flutter.dart';

import '../config/config.dart';

class LoginPage extends StatefulWidget {
  @override
  _LoginPageState createState() => _LoginPageState();
}

class _LoginPageState extends State<LoginPage> {
  final _LivechatSdkFlutterPlugin = LivechatSdkFlutter();
  final _formKey = GlobalKey<FormState>();
  String? _enterpriseId;
  String? _accessId;
  String? _accessSecret;

  final _enterpriseIdController = TextEditingController(text: '8000002');
  final _accessIdController =
      TextEditingController(text: '8758096679544ff189d4a9457747f109');
  final _accessSecretController =
      TextEditingController(text: '72EBF29CB4614F7AB404EEC07BFF0B1B');

  @override
  void dispose() {
    _enterpriseIdController.dispose();
    _accessIdController.dispose();
    _accessSecretController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: Container(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            SizedBox(
              height: 24,
            ),
            Container(
              height: 44,
              child: GestureDetector(
                child: Padding(
                  padding:
                      EdgeInsets.only(left: 16, top: 10, bottom: 10, right: 16),
                  child: Image.asset(
                    'images/left_back.png',
                    height: 24.0,
                    width: 24.0,
                  ),
                ),
                onTap: () {
                  Navigator.pop(context);
                },
              ),
            ),
            Expanded(
              flex: 1,
              child: Padding(
                padding: EdgeInsets.only(left: 32, right: 32),
                child: Form(
                  key: _formKey,
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      Image.asset(
                        'images/logo.png',
                        width: 84,
                        height: 84,
                      ),
                      Text(
                        '访客端 Flutter Plugin',
                        style: TextStyle(
                          color: Color.fromRGBO(89, 89, 89, 1),
                          fontSize: 24,
                        ),
                      ),
                      SizedBox(height: 4),
                      Text(
                        '让客户联络效率更高，体验更好',
                        style: TextStyle(
                          color: Color.fromRGBO(140, 140, 140, 1),
                          fontSize: 12,
                        ),
                      ),
                      SizedBox(height: 46.0),
                      TextFormField(
                        controller: _enterpriseIdController,
                        keyboardType: TextInputType.number,
                        decoration: InputDecoration(
                          labelText: '请输入企业 ID',
                          labelStyle: TextStyle(
                            fontSize: 15,
                          ),
                        ),
                        onSaved: (value) {
                          _enterpriseId = value;
                        },
                      ),
                      TextFormField(
                        controller: _accessIdController,
                        decoration: InputDecoration(
                          labelText: '请输入 Access ID',
                          labelStyle: TextStyle(
                            fontSize: 15,
                          ),
                        ),
                        onSaved: (value) {
                          _accessId = value;
                        },
                      ),
                      TextFormField(
                        controller: _accessSecretController,
                        obscureText: true,
                        decoration: InputDecoration(
                          labelText: '请输入 Access Secret',
                          labelStyle: TextStyle(
                            fontSize: 15,
                          ),
                        ),
                        onSaved: (value) {
                          _accessSecret = value;
                        },
                      ),
                      SizedBox(
                        height: 24,
                      ),
                      GestureDetector(
                        onTap: () {
                          if (_formKey.currentState!.validate()) {
                            _formKey.currentState!.save();
                            // : 调用SDK初始化及连接
                            _initAndConnect();
                          }
                        },
                        child: Container(
                          width: 311,
                          height: 48,
                          decoration: BoxDecoration(
                            color: Color.fromRGBO(67, 133, 255, 1),
                            borderRadius: BorderRadius.all(Radius.circular(8)),
                          ),
                          child: Center(
                            child: Text(
                              '接入',
                              style:
                                  TextStyle(color: Colors.white, fontSize: 16),
                            ),
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            )
          ],
        ),
      ),
    );
  }

  void _initAndConnect() {
    _LivechatSdkFlutterPlugin.initPlugin({
      "enterpriseId": _enterpriseId,
      "accessId": _accessId,
      "accessSecret": _accessSecret,
      "apiUrl": Config.apiUrlDefaultValue,
      "onlineUrl": Config.onlineUrlDefaultValue,
      "debug": true,
    }).then((value) {
      _LivechatSdkFlutterPlugin
          .enterSession(Config.enterSessionDefaultParameters)
          .then((value) {
        _LivechatSdkFlutterPlugin.listen(_onData, onError: _onError);
      }).onError((error, stackTrace) {
        // Fluttertoast.showToast(
        //     msg: (error as PlatformException).message.toString(),
        //     toastLength: Toast.LENGTH_SHORT);
      });
    }).onError((error, stackTrace) {
      // Fluttertoast.showToast(
      //     msg: (error as PlatformException).message.toString(),
      //     toastLength: Toast.LENGTH_SHORT);
    });
  }

  void _onData(data) {
    //返回的内容
    print('测试返回内容 正确回调');
    print(data);
  }

  void _onError(error) {
    //返回的回调
    print('测试返回内容 错误回调');
    print(error);
  }
}
