import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:livechat_sdk_flutter/livechat_sdk_flutter.dart';

import '../config/config.dart';
import '../config/routers.dart';

class HomePage extends StatefulWidget {
  const HomePage({super.key});

  @override
  State<HomePage> createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  final _LivechatSdkFlutterPlugin = LivechatSdkFlutter();

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  Future<void> initPlatformState() async {
    _LivechatSdkFlutterPlugin.initPlugin(Config.initPluginDefaultParameters);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        body: Container(
          width: double.maxFinite,
          height: double.maxFinite,
          decoration: BoxDecoration(
            image: DecorationImage(
              fit: BoxFit.fill,
              image: AssetImage('images/splash_bg.png'),
            ),
          ),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              SizedBox(height: 144),
              ClipRRect(
                borderRadius: BorderRadius.all(Radius.circular(20)),
                child: Image.asset(
                  'images/logo.png',
                  width: 84,
                  height: 84,
                  fit: BoxFit.cover,
                ),
              ),
              SizedBox(height: 12),
              Text(
                '访客端 Flutter Plugin',
                style: TextStyle(
                  color: Color.fromRGBO(89, 89, 89, 1),
                  fontSize: 24,
                ),
              ),
              SizedBox(height: 4),
              Text(
                '让客户联络效率更高，体验更好',
                style: TextStyle(
                  color: Color.fromRGBO(140, 140, 140, 1),
                  fontSize: 12,
                ),
              ),
              SizedBox(height: 86),
              GestureDetector(
                onTap: () {
                  Navigator.pushNamed(context, Routers.webView);
                },
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    Image.asset(
                      'images/doc_icon.png',
                      width: 24,
                      height: 24,
                    ),
                    SizedBox(height: 8),
                    Text(
                      '接入文档',
                      style: TextStyle(
                        color: Color.fromRGBO(67, 133, 255, 1),
                        fontSize: 14,
                      ),
                    ),
                  ],
                ),
              ),
              SizedBox(
                height: 66,
              ),
              GestureDetector(
                onTap: () {
                  _experienceNow();
                },
                child: Container(
                  width: 311,
                  height: 48,
                  decoration: BoxDecoration(
                    color: Color.fromRGBO(67, 133, 255, 1),
                    borderRadius: BorderRadius.all(Radius.circular(8)),
                  ),
                  child: Center(
                    child: Text(
                      '立即体验',
                      style: TextStyle(color: Colors.white, fontSize: 16),
                    ),
                  ),
                ),
              ),
              SizedBox(
                height: 16,
              ),
              GestureDetector(
                onTap: () {
                  print('进入接入页面');
                  Navigator.pushNamed(context, Routers.access);
                },
                child: Container(
                  width: 311,
                  height: 48,
                  decoration: BoxDecoration(
                    color: Color.fromRGBO(255, 255, 255, 0.55),
                    borderRadius: BorderRadius.all(Radius.circular(8)),
                  ),
                  child: Center(
                    child: Text(
                      '接入',
                      style: TextStyle(
                          color: Color.fromRGBO(67, 133, 255, 1), fontSize: 16),
                    ),
                  ),
                ),
              )
            ],
          ),
        ),
      ),
    );
  }

  void _experienceNow() {
    log('快速接入页面');
    _LivechatSdkFlutterPlugin
        .enterSession(Config.enterSessionDefaultParameters)
        .then((value) {
      _LivechatSdkFlutterPlugin.listen(_onData, onError: _onError);
    }).onError((error, stackTrace) {
      // Fluttertoast.showToast(
      //     msg: (error as PlatformException).message.toString(),
      //     toastLength: Toast.LENGTH_SHORT);
    });
  }

  void _onData(data) {
    //返回的内容
    print('测试返回内容 正确回调');
    print(data);
  }

  void _onError(error) {
    //返回的回调
    print('测试返回内容 错误回调');
    print(error);
  }
}
