import 'package:flutter/services.dart';

import 'livechat_sdk_flutter_platform_interface.dart';

/// An implementation of [LivechatSdkFlutterPlatform] that uses method channels.
class MethodChannelLivechatSdkFlutter extends LivechatSdkFlutterPlatform {
  final String methodInitPlugin = "method_init_plugin";

  final String methodEnterSession = "method_enter_session";

  final String methodDisconnect = "method_disconnect";

  final String methodGetCurrentUserInfo = "method_get_current_user_info";

  final String methodGetCurrentSessionInfo = "method_get_current_session_info";

  final String methodGetCurrentOnlineStatus =
      "method_get_current_online_status";

  final String methodUpdateSessionWindowQuickEntry =
      "method_update_session_window_quick_entry";

  final String methodGetSdkVersion = "method_get_sdk_version";

  final methodChannel = const MethodChannel("method_channel_flutter_tos_kit");

  final eventChannel = const EventChannel("event_channel_flutter_tos_kit");

  Future<String?> getPlatformVersion() async {
    final version =
    await methodChannel.invokeMethod<String>('getPlatformVersion');
    return version;
  }

  Future<String?> startActivity() async {
    final version = await methodChannel.invokeMethod<String>('startActivity');
    return version;
  }

  @override
  Future<bool?> initPlugin(params) async {
    final result =
    await methodChannel.invokeMethod<bool>(methodInitPlugin, params);
    return result;
  }

  @override
  Future<bool?> enterSession(params) async {
    final result =
    await methodChannel.invokeMethod<bool>(methodEnterSession, params);
    return result;
  }

  @override
  Future<bool?> disConnect() async {
    final result = await methodChannel.invokeMethod<bool>(methodDisconnect);
    return result;
  }

  @override
  Future<String?> getCurrentUserInfo() async {
    final result =
    await methodChannel.invokeMethod<String>(methodGetCurrentUserInfo);
    return result;
  }

  @override
  Future<String?> getCurrentSessionInfo() async {
    final result =
    await methodChannel.invokeMethod<String>(methodGetCurrentSessionInfo);
    return result;
  }

  @override
  Future<int?> getCurrentOnlineStatus() async {
    final result =
    await methodChannel.invokeMethod<int>(methodGetCurrentOnlineStatus);
    return result;
  }

  @override
  Future<bool?> updateSessionWindowQuickEntry(params) async {
    final result = await methodChannel.invokeMethod<bool>(
        methodUpdateSessionWindowQuickEntry, params);
    return result;
  }

  @override
  Future<String?> getSdkVersion() async {
    final result =
    await methodChannel.invokeMethod<String>(methodGetSdkVersion);
    return result;
  }

  @override
  void listen(void Function(dynamic event)? onData,
      {Function? onError, void Function()? onDone, bool? cancelOnError}) {
    eventChannel.receiveBroadcastStream().listen(onData,
        onError: onError, onDone: onDone, cancelOnError: cancelOnError);
  }
}
