import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'livechat_sdk_flutter_method_channel.dart';

abstract class LivechatSdkFlutterPlatform extends PlatformInterface {
  /// Constructs a LivechatSdkFlutterPlatform.
  LivechatSdkFlutterPlatform() : super(token: _token);

  static final Object _token = Object();

  static LivechatSdkFlutterPlatform _instance = MethodChannelLivechatSdkFlutter();

  /// The default instance of [LivechatSdkFlutterPlatform] to use.
  ///
  /// Defaults to [MethodChannelLivechatSdkFlutter].
  static LivechatSdkFlutterPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [LivechatSdkFlutterPlatform] when
  /// they register themselves.
  static set instance(LivechatSdkFlutterPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<bool?> initPlugin(params) {
    throw UnimplementedError('initPlugin() has not been implemented.');
  }

  Future<bool?> enterSession(params) {
    throw UnimplementedError('enterSession() has not been implemented.');
  }

  Future<bool?> disConnect() async {
    throw UnimplementedError('disConnect() has not been implemented.');
  }

  Future<String?> getCurrentUserInfo() async {
    throw UnimplementedError('getCurrentUserInfo() has not been implemented.');
  }

  Future<String?> getCurrentSessionInfo() async {
    throw UnimplementedError(
        'getCurrentSessionInfo() has not been implemented.');
  }

  Future<int?> getCurrentOnlineStatus() async {
    throw UnimplementedError(
        'getCurrentOnlineStatus() has not been implemented.');
  }

  Future<bool?> updateSessionWindowQuickEntry(params) async {
    throw UnimplementedError(
        'updateSessionWindowQuickEntry() has not been implemented.');
  }

  Future<String?> getSdkVersion() async {
    throw UnimplementedError('getSdkVersion() has not been implemented.');
  }

  void listen(void Function(dynamic event)? onData,
      {Function? onError, void Function()? onDone, bool? cancelOnError}) {
    throw UnimplementedError('enterSession() has not been implemented.');
  }
}
